import datamaestro

class Repository(datamaestro.Repository):
    AUTHOR = """Benjamin Piwowarski <benjamin@piwowarski.fr>"""
    DESCRIPTION = """Machine learning datamaestro repository"""
    NAMESPACE = """ml"""